From 196bce3176a224b988a3749248609adc18598554 Mon Sep 17 00:00:00 2001
From: Pierre d'Herbemont <pdherbemont@videolan.org>
Date: Sun, 6 Jan 2008 21:45:41 +0000
Subject: [PATCH] MacOSX: Make sure VLC.framework is renamed to
 VLCKit.framework.

---
 .../Headers/Internal/VLCLibVLCBridging.h      |  1 +
 .../Headers/Public/VLCMediaDiscoverer.h       |  2 +-
 extras/MacOSX/Framework/VLC_Prefix.pch        | 37 -------------------
 extras/MacOSX/VLC_app/Sources/VLCController.m |  3 +-
 .../VLC_app/VLC.xcodeproj/project.pbxproj     |  4 +-
 src/misc/darwin_specific.c                    |  8 ++--
 6 files changed, 9 insertions(+), 46 deletions(-)

diff --git a/extras/MacOSX/Framework/Headers/Internal/VLCLibVLCBridging.h b/extras/MacOSX/Framework/Headers/Internal/VLCLibVLCBridging.h
index 4429be8fcdd0..2e9156c10cf5 100644
--- a/extras/MacOSX/Framework/Headers/Internal/VLCLibVLCBridging.h
+++ b/extras/MacOSX/Framework/Headers/Internal/VLCLibVLCBridging.h
@@ -23,6 +23,7 @@
 *****************************************************************************/
 
 #import "VLCLibrary.h"
+#import "VLCMediaListAspect.h"
 
 /**
  * Bridges functionality between libvlc and VLCMediaList implementation.
diff --git a/extras/MacOSX/Framework/Headers/Public/VLCMediaDiscoverer.h b/extras/MacOSX/Framework/Headers/Public/VLCMediaDiscoverer.h
index 2967b836fe1c..2041ffa74680 100644
--- a/extras/MacOSX/Framework/Headers/Public/VLCMediaDiscoverer.h
+++ b/extras/MacOSX/Framework/Headers/Public/VLCMediaDiscoverer.h
@@ -23,7 +23,7 @@
  *****************************************************************************/
 
 #import <Cocoa/Cocoa.h>
-#import <VLC/VLCMediaList.h>
+#import <VLCKit/VLCMediaList.h>
 
 @class VLCMediaList;
 
diff --git a/extras/MacOSX/Framework/VLC_Prefix.pch b/extras/MacOSX/Framework/VLC_Prefix.pch
index 64a47940b4f0..c4340c70492e 100644
--- a/extras/MacOSX/Framework/VLC_Prefix.pch
+++ b/extras/MacOSX/Framework/VLC_Prefix.pch
@@ -2,49 +2,12 @@
 // Prefix header for all source files of the 'VLC' target in the 'VLC' project.
 //
 
-#ifdef __OBJC__
-    #import <Cocoa/Cocoa.h>
-#endif
-
-#include <vlc/vlc.h>
-
-#ifndef VLC_PUBLIC_API
-
-// For some reason Xcode refuses to read vlc/vlc.h contents -- so we have to do
-// this so we can supress the errors
-#define VLC_PUBLIC_API extern
-typedef int vlc_bool_t;
-typedef struct vlc_list_t vlc_list_t;
-typedef struct vlc_object_t vlc_object_t;
-typedef signed long long vlc_int64_t;
-
-#endif
-
-#include <vlc/libvlc_structures.h>
-#include <vlc/libvlc.h>
-
-//
-// Prefix header for all source files of the 'VLC' target in the 'VLC' project.
-//
 
 #ifdef __OBJC__
     #import <Cocoa/Cocoa.h>
 #endif
 
 #include <vlc/vlc.h>
-
-#ifndef VLC_PUBLIC_API
-
-// For some reason Xcode refuses to read vlc/vlc.h contents -- so we have to do
-// this so we can supress the errors
-#define VLC_PUBLIC_API extern
-typedef int vlc_bool_t;
-typedef struct vlc_list_t vlc_list_t;
-typedef struct vlc_object_t vlc_object_t;
-typedef signed long long vlc_int64_t;
-
-#endif
-
 #include <vlc/libvlc_structures.h>
 #include <vlc/libvlc.h>
 
diff --git a/extras/MacOSX/VLC_app/Sources/VLCController.m b/extras/MacOSX/VLC_app/Sources/VLCController.m
index af9ce8eed159..38a5e3854e14 100644
--- a/extras/MacOSX/VLC_app/Sources/VLCController.m
+++ b/extras/MacOSX/VLC_app/Sources/VLCController.m
@@ -59,8 +59,7 @@
     NSArray * mediaDiscoverers = [NSArray arrayWithObjects:
         [[[VLCMediaDiscoverer alloc] initWithName:@"shoutcasttv"] autorelease],
         [[[VLCMediaDiscoverer alloc] initWithName:@"shoutcast"] autorelease],
-        [[[VLCMediaDiscoverer alloc] initWithName:@"sap"] autorelease],
-        [[[VLCMediaDiscoverer alloc] initWithName:@"freebox"] autorelease], nil];
+        [[[VLCMediaDiscoverer alloc] initWithName:@"sap"] autorelease], nil];
 
     NSArray * playlists = [NSMutableArray arrayWithObjects:[VLCMedia mediaAsNodeWithName:@"Default Playlist"], nil];
 
diff --git a/extras/MacOSX/VLC_app/VLC.xcodeproj/project.pbxproj b/extras/MacOSX/VLC_app/VLC.xcodeproj/project.pbxproj
index c4e3aefa695b..848aa0b079a6 100644
--- a/extras/MacOSX/VLC_app/VLC.xcodeproj/project.pbxproj
+++ b/extras/MacOSX/VLC_app/VLC.xcodeproj/project.pbxproj
@@ -413,10 +413,10 @@
 			files = (
 			);
 			inputPaths = (
-				$SRCROOT/../Framework/build/$BUILD_VARIANTS/VLC.framework,
+				$SRCROOT/../Framework/build/$BUILD_VARIANTS/VLCKit.framework,
 			);
 			outputPaths = (
-				$BUILT_PRODUCTS_DIR/$FRAMEWORKS_FOLDER_PATH/VLC.framework,
+				$BUILT_PRODUCTS_DIR/$FRAMEWORKS_FOLDER_PATH/VLCKit.framework,
 			);
 			runOnlyForDeploymentPostprocessing = 0;
 			shellPath = /bin/sh;
diff --git a/src/misc/darwin_specific.c b/src/misc/darwin_specific.c
index 77dff2f85e40..c45cc437a919 100644
--- a/src/misc/darwin_specific.c
+++ b/src/misc/darwin_specific.c
@@ -76,13 +76,13 @@ void system_Init( libvlc_int_t *p_this, int *pi_argc, char *ppsz_argv[] )
     for (i = 0; i < _dyld_image_count(); i++)
     {
         char * psz_img_name = _dyld_get_image_name(i);
         /* Check for "VLC.framework/Versions/Current/VLC",
          * as well as "VLC.framework/Versions/A/VLC" and
          * "VLC.framework/Versions/B/VLC" */
-        if( p_char = strstr( psz_img_name, "VLC.framework/Versions/" ))
+        if( p_char = strstr( psz_img_name, "VLCKit.framework/Versions/" ))
         {
             /* Look for the next forward slash */
-            p_char += 23; /* p_char += strlen(" VLC.framework/Versions/" ) */
+            p_char += 26; /* p_char += strlen(" VLCKit.framework/Versions/" ) */
             while( *p_char != '\0' && *p_char != '/')
                 p_char++;
             
@@ -76,13 +76,13 @@ void system_Init( libvlc_int_t *p_this, int *pi_argc, char *ppsz_argv[] )
     {
         char * psz_img_name = _dyld_get_image_name(i);
-        /* Check for "VLC.framework/Versions/Current/VLC",
-         * as well as "VLC.framework/Versions/A/VLC" and
+        /* Check for "VLCKit.framework/Versions/Current/VLC",
+         * as well as "VLCKit.framework/Versions/A/VLC" and
          * "VLC.framework/Versions/B/VLC" */
-- 
GitLab